#!/usr/bin/env python

import os, sys, time, argparse, shutil

def manage_console():
    parser = argparse.ArgumentParser()

    parser.add_argument('-project', '-startproject', '-p', type=str, help='Create project' )
    parser.add_argument('-app', '-startapp', '-a',         type=str, help='Create app'     )
    args = parser.parse_args()

    print( 'args.project', args.project)

    path_root = os.path.dirname(__file__)

    if '/core' in path_root:
        path_root = path_root[:-5]
    else:
        __import__('tao1')
        module = sys.modules['tao1']
        path_root = os.path.dirname( os.path.abspath(module.__file__) )

    if args.project is not None:
        shutil.copytree(  os.path.join( path_root , 'sites', 'daoerp'), os.path.join( str(args.project) ) )
        set_file = """
import os

session_key = b'Sixteen byte key'

debug = True

root_path = os.path.dirname(__file__)
tao_path  = '%s'

database={"login":"admin", "pass":"passwd", "host":["127.0.0.1:27017"], 'name':'test'}
        """ % path_root
        with open(os.path.join( str(args.project) , 'settings.py'), 'w') as f: f.write(set_file)

    elif args.app != None:
        shutil.copytree( os.path.join( path_root, 'apps', 'app'), os.path.join( str(args.app) ) )

    print( args )

# if __name__ == "__main__":
#     manage_console()


















#!/usr/bin/env python
# coding: utf-8

import sys, os
assert sys.version >= '3.3', 'Please use Python 3.4 or higher.'


import settings
sys.path.append(settings.root)
sys.path.append( os.path.dirname( __file__ ) )

from tao1.core.union import init_gunicorn
app = init_gunicorn()

# gunicorn app:app -k aiohttp.worker.GunicornWebWorker -b localhost:6677



import os, time, asyncio

from pymongo import *

import settings

def die(mess):
    raise Exception(str(mess))

# @asyncio.coroutine
# def server_connect():
# 	if not db_conn['conn']:
# 		db = get_settings('database', {} )
# 		kw = {}
# 		db_conn['conn'] = MongoClient(db['host'], **kw)
# 	return db_conn['conn']
# @asyncio.coroutine
# def connect():
#     db = get_settings('database', {} )
#     mongo = MongoClient(db['host'], db['port'])
#     print( mongo)
#     db = mongo['tok']
#     db.authenticate('admin', settings.database['pass'] )
#     return db

@asyncio.coroutine
def get_settings(name, def_val=None):
    if name in settings.__dict__: return settings.__dict__[name]
    else: return def_val


@asyncio.coroutine
def locale_date(format, dt, loc = 'en_US.UTF-8'):
    """ dt - кортеж """
    import locale
    lc = locale.getdefaultlocale()
    # lc = locale.getlocale(locale.LC_ALL)
    locale.setlocale(locale.LC_ALL, loc)
    res = time.strftime(format, dt)
    locale.setlocale(locale.LC_ALL, lc)
    return res



import sys, os, time, asyncio, jinja2, aiohttp_jinja2
from aiohttp import web
import aiohttp
from aiohttp.web import Application, Response, MsgType, WebSocketResponse

from core.union import cache

from pymongo import *
# from gridfs import GridFS
from aiohttp_session import get_session

# @cache("main_page", expire=25)
@asyncio.coroutine
def page(request):
    # for a in dir(response):
    #     attr = getattr(response, a))
    #     print('  == {}: {} :: {}'.format(a, type(attr).__name__, repr(attr))
    return templ('apps.app:index', request, {'key':'val'} )


@asyncio.coroutine
def test_db(request):
    session = yield from get_session(request)
    session['last_visit'] = time.time()
    request.db.doc.save({"_id":"test", "val":"test_db", "status":"success"})
    val = request.db.doc.find_one({"_id":"test"})
    return templ('apps.app:db_test', request, {'key':val})


@asyncio.coroutine
def ws(request):
    return templ('apps.app:chat', request, {} )

@asyncio.coroutine
def ws_handler(request):
    ws = web.WebSocketResponse()
    ws.start(request)
    while True:
        msg = yield from ws.receive()
        if msg.tp == MsgType.text:
            if msg.data == 'close':
                yield from ws.close()
            else:
                ws.send_str(msg.data + '/answer')
        elif msg.tp == aiohttp.MsgType.close: print('websocket connection closed')
        elif msg.tp == aiohttp.MsgType.error: print('ws connection closed with exception %s', ws.exception())
    return ws




























